function _interopDefault (ex) { return (ex && (typeof ex === 'object') && 'default' in ex) ? ex['default'] : ex; }

var React = require('react');
var React__default = _interopDefault(React);
var SASjs = _interopDefault(require('@sasjs/adapter'));
var semanticUiReact = require('semantic-ui-react');
var immer = require('immer');
var SyntaxHighlighter = _interopDefault(require('react-syntax-highlighter'));
var moment = _interopDefault(require('moment'));
var reactHelmet = require('react-helmet');

var AppContext = React.createContext({
  config: null,
  sasJsConfig: null,
  isLoggedIn: false,
  setIsLoggedIn: null,
  adapter: null
});
var AppProvider = function AppProvider(props) {
  var _useState = React.useState({
    sasJsConfig: null
  }),
      config = _useState[0],
      setConfig = _useState[1];

  var _useState2 = React.useState(null),
      adapter = _useState2[0],
      setAdapter = _useState2[1];

  var _useState3 = React.useState(false),
      isLoggedIn = _useState3[0],
      setIsLoggedIn = _useState3[1];

  React.useEffect(function () {
    fetch('config.json').then(function (res) {
      return res.json();
    }).then(function (configJson) {
      setConfig(configJson);
      var sasjs = new SASjs(configJson.sasJsConfig);
      setAdapter(sasjs);
      sasjs.checkSession().then(function (response) {
        setIsLoggedIn(response.isLoggedIn);
      });
    });
  }, []);
  return React__default.createElement(AppContext.Provider, {
    value: {
      config: config,
      sasJsConfig: config.sasJsConfig,
      isLoggedIn: isLoggedIn,
      setIsLoggedIn: setIsLoggedIn,
      adapter: adapter
    }
  }, props.children);
};

function _extends() {
  _extends = Object.assign || function (target) {
    for (var i = 1; i < arguments.length; i++) {
      var source = arguments[i];

      for (var key in source) {
        if (Object.prototype.hasOwnProperty.call(source, key)) {
          target[key] = source[key];
        }
      }
    }

    return target;
  };

  return _extends.apply(this, arguments);
}

// A type of promise-like that resolves synchronously and supports only one observer
const _Pact = /*#__PURE__*/(function() {
	function _Pact() {}
	_Pact.prototype.then = function(onFulfilled, onRejected) {
		const result = new _Pact();
		const state = this.s;
		if (state) {
			const callback = state & 1 ? onFulfilled : onRejected;
			if (callback) {
				try {
					_settle(result, 1, callback(this.v));
				} catch (e) {
					_settle(result, 2, e);
				}
				return result;
			} else {
				return this;
			}
		}
		this.o = function(_this) {
			try {
				const value = _this.v;
				if (_this.s & 1) {
					_settle(result, 1, onFulfilled ? onFulfilled(value) : value);
				} else if (onRejected) {
					_settle(result, 1, onRejected(value));
				} else {
					_settle(result, 2, value);
				}
			} catch (e) {
				_settle(result, 2, e);
			}
		};
		return result;
	};
	return _Pact;
})();

// Settles a pact synchronously
function _settle(pact, state, value) {
	if (!pact.s) {
		if (value instanceof _Pact) {
			if (value.s) {
				if (state & 1) {
					state = value.s;
				}
				value = value.v;
			} else {
				value.o = _settle.bind(null, pact, state);
				return;
			}
		}
		if (value && value.then) {
			value.then(_settle.bind(null, pact, state), _settle.bind(null, pact, 2));
			return;
		}
		pact.s = state;
		pact.v = value;
		const observer = pact.o;
		if (observer) {
			observer(pact);
		}
	}
}

function _isSettledPact(thenable) {
	return thenable instanceof _Pact && thenable.s & 1;
}

// Asynchronously iterate through an object that has a length property, passing the index as the first argument to the callback (even as the length property changes)
function _forTo(array, body, check) {
	var i = -1, pact, reject;
	function _cycle(result) {
		try {
			while (++i < array.length && (!check || !check())) {
				result = body(i);
				if (result && result.then) {
					if (_isSettledPact(result)) {
						result = result.v;
					} else {
						result.then(_cycle, reject || (reject = _settle.bind(null, pact = new _Pact(), 2)));
						return;
					}
				}
			}
			if (pact) {
				_settle(pact, 1, result);
			} else {
				pact = result;
			}
		} catch (e) {
			_settle(pact || (pact = new _Pact()), 2, e);
		}
	}
	_cycle();
	return pact;
}

const _iteratorSymbol = /*#__PURE__*/ typeof Symbol !== "undefined" ? (Symbol.iterator || (Symbol.iterator = Symbol("Symbol.iterator"))) : "@@iterator";

const _asyncIteratorSymbol = /*#__PURE__*/ typeof Symbol !== "undefined" ? (Symbol.asyncIterator || (Symbol.asyncIterator = Symbol("Symbol.asyncIterator"))) : "@@asyncIterator";

var TestCard = function TestCard(props) {
  var title = props.title,
      description = props.description,
      status = props.status,
      error = props.error,
      executionTime = props.executionTime,
      onRerun = props.onRerun;
  return React__default.createElement("div", {
    className: "test"
  }, React__default.createElement("div", null, React__default.createElement("code", {
    className: "title"
  }, title), !!onRerun && React__default.createElement("button", {
    className: "re-run-button " + (status === 'running' ? 'disabled' : ''),
    onClick: onRerun
  }, status === 'running' ? 'Running' : 'Re-run')), React__default.createElement("span", {
    className: "description"
  }, description), React__default.createElement("span", {
    className: "execution-time"
  }, executionTime ? executionTime.toFixed(2) + 's' : ''), status === 'running' && React__default.createElement("div", null, React__default.createElement("span", {
    className: "icon running"
  }), "Running..."), status === 'passed' && React__default.createElement("div", null, React__default.createElement("span", {
    className: "icon passed"
  }), "Passed"), status === 'failed' && React__default.createElement("div", null, React__default.createElement("div", null, React__default.createElement("span", {
    className: "icon failed"
  }), "Failed"), !!error && React__default.createElement("code", null, error.message)));
};

var getStatus = function getStatus(isRunning, isPassed) {
  return isRunning ? 'running' : isPassed ? 'passed' : 'failed';
};

var Test = function Test(props) {
  var title = props.title,
      description = props.description,
      test = props.test,
      beforeTest = props.beforeTest,
      afterTest = props.afterTest,
      assertion = props.assertion,
      onCompleted = props.onCompleted,
      onRerun = props.onRerun,
      context = props.context;
  var beforeTestFunction = beforeTest ? beforeTest : function () {
    return Promise.resolve();
  };
  var afterTestFunction = afterTest ? afterTest : function () {
    return Promise.resolve();
  };

  var _useState = React.useState(false),
      isRunning = _useState[0],
      setIsRunning = _useState[1];

  var _useState2 = React.useState(false),
      isPassed = _useState2[0],
      setIsPassed = _useState2[1];

  React.useEffect(function () {
    if (test && assertion) {
      var startTime = new Date().valueOf();
      setIsRunning(true);
      setIsPassed(false);
      beforeTestFunction().then(function () {
        return test(context);
      }).then(function (res) {
        setIsRunning(false);
        setIsPassed(assertion(res, context));
        return Promise.resolve(assertion(res, context));
      }).then(function (testResult) {
        afterTestFunction();
        var endTime = new Date().valueOf();
        var executionTime = (endTime - startTime) / 1000;
        onCompleted({
          result: testResult,
          error: null,
          executionTime: executionTime
        });
      })["catch"](function (e) {
        setIsRunning(false);
        setIsPassed(false);
        console.error(e);
        var endTime = new Date().valueOf();
        var executionTime = (endTime - startTime) / 1000;
        onCompleted({
          result: false,
          error: e,
          executionTime: executionTime
        });
      });
    }
  }, [test, assertion]);
  return React__default.createElement(TestCard, {
    title: title,
    onRerun: onRerun,
    description: description,
    status: getStatus(isRunning, isPassed),
    error: null
  });
};

var TestSuite = function TestSuite(props) {
  var name = props.name,
      tests = props.tests,
      beforeAll = props.beforeAll,
      afterAll = props.afterAll,
      _onCompleted = props.onCompleted;

  var _useState = React.useState(null),
      context = _useState[0],
      setContext = _useState[1];

  var _useState2 = React.useState([]),
      completedTests = _useState2[0],
      setCompletedTests = _useState2[1];

  var _useState3 = React.useState(null),
      currentTest = _useState3[0],
      setCurrentTest = _useState3[1];

  React.useEffect(function () {
    if (beforeAll) {
      beforeAll().then(function (data) {
        return setContext({
          data: data
        });
      });
    }
  }, [beforeAll]);
  React.useEffect(function () {
    if (tests.length) {
      setCurrentTest(tests[0]);
    }

    setCompletedTests([]);
    setContext(null);
  }, [tests]);
  return !!beforeAll && !!context || !beforeAll ? React__default.createElement("div", {
    className: "test-suite"
  }, React__default.createElement("div", {
    className: "test-suite-name running"
  }, name), currentTest && React__default.createElement(Test, Object.assign({}, currentTest, {
    context: context,
    onRerun: function onRerun() {
      var newCompleteTests = completedTests.filter(function (t) {
        return t.test.title !== currentTest.title;
      });
      setCompletedTests(newCompleteTests);
      setCurrentTest(currentTest);
    },
    onCompleted: function onCompleted(completedTest) {
      var newCompleteTests = [{
        test: currentTest,
        result: completedTest.result,
        error: completedTest.error,
        executionTime: completedTest.executionTime
      }].concat(completedTests);
      setCompletedTests(newCompleteTests);
      var currentIndex = tests.indexOf(currentTest);
      var nextIndex = currentIndex < tests.length - 1 ? currentIndex + 1 : -1;

      if (nextIndex >= 0) {
        setCurrentTest(tests[nextIndex]);
      } else {
        setCurrentTest(null);
      }

      if (newCompleteTests.length === tests.length) {
        if (afterAll) {
          afterAll().then(function () {
            _onCompleted(name, newCompleteTests);
          });
        } else {
          _onCompleted(name, newCompleteTests);
        }
      }
    }
  })), completedTests.map(function (completedTest, index) {
    var test = completedTest.test,
        result = completedTest.result,
        error = completedTest.error;
    var title = test.title,
        description = test.description;
    return React__default.createElement(TestCard, {
      key: index,
      onRerun: function onRerun() {
        var newCompleteTests = completedTests.filter(function (t) {
          return t.test !== currentTest;
        });
        setCompletedTests(newCompleteTests);
        setCurrentTest(currentTest);
      },
      title: title,
      description: description,
      status: result === true ? 'passed' : 'failed',
      error: error
    });
  })) : React__default.createElement("div", null);
};

var decodeHtml = function decodeHtml(encodedString) {
  var tempElement = document.createElement('textarea');
  tempElement.innerHTML = encodedString;
  return tempElement.value;
};

var RequestsModal = function RequestsModal(props) {
  var trigger = props.trigger;

  var _useContext = React.useContext(AppContext),
      adapter = _useContext.adapter;

  var _useState = React.useState([]),
      requests = _useState[0],
      setRequests = _useState[1];

  var config = adapter.getSasjsConfig();

  var _useState2 = React.useState(-1),
      activeIndex = _useState2[0],
      setActiveIndex = _useState2[1];

  React.useEffect(function () {
    setRequests(adapter.getSasRequests());
  }, []);
  return React__default.createElement(semanticUiReact.Modal, {
    basic: true,
    onOpen: function onOpen() {
      return setRequests(adapter.getSasRequests());
    },
    closeIcon: true,
    trigger: trigger,
    size: "fullscreen",
    className: "requests-modal"
  }, React__default.createElement(semanticUiReact.Modal.Header, null, config.debug ? 'Last 20 requests' : ''), React__default.createElement(semanticUiReact.Modal.Content, null, config.debug ? requests && requests.length ? React__default.createElement(semanticUiReact.Accordion, {
    inverted: true,
    className: "requests-accordion"
  }, requests.map(function (request, index) {
    return React__default.createElement("div", {
      key: index
    }, React__default.createElement(semanticUiReact.Accordion.Title, {
      className: "requests-accordion-title",
      active: activeIndex === index,
      index: index,
      onClick: function onClick() {
        return setActiveIndex(activeIndex === index ? -1 : index);
      }
    }, request.serviceLink + "  ", React__default.createElement("span", {
      className: "request-timestamp"
    }, moment(request.timestamp).format('dddd, MMMM Do YYYY, h:mm:ss a'), " (" + moment(request.timestamp).fromNow() + ")")), React__default.createElement(semanticUiReact.Accordion.Content, {
      active: activeIndex === index
    }, React__default.createElement("div", {
      className: "requests-item"
    }, React__default.createElement(semanticUiReact.Tab, {
      className: "request-tabs",
      renderActiveOnly: true,
      style: {
        width: '100%'
      },
      menu: {
        fluid: true,
        secondary: true,
        inverted: true
      },
      panes: [{
        menuItem: 'Log',
        render: function render() {
          return React__default.createElement(SyntaxHighlighter, {
            language: "html"
          }, decodeHtml(request.logFile));
        }
      }, {
        menuItem: 'Source Code',
        render: function render() {
          return React__default.createElement(SyntaxHighlighter, {
            language: "sas"
          }, decodeHtml(request.sourceCode));
        }
      }, {
        menuItem: 'Generated Code',
        render: function render() {
          return React__default.createElement(SyntaxHighlighter, {
            language: "sas"
          }, decodeHtml(request.generatedCode));
        }
      }]
    }))));
  })) : React__default.createElement("div", {
    className: "debug-message"
  }, React__default.createElement(semanticUiReact.Icon, {
    name: "bug",
    size: "huge",
    inverted: true
  }), React__default.createElement("h3", null, "There are no requests available."), React__default.createElement("span", null, "Please run a test and check again.")) : React__default.createElement("div", {
    className: "debug-message"
  }, React__default.createElement(semanticUiReact.Icon, {
    name: "bug",
    size: "huge",
    inverted: true
  }), React__default.createElement("h3", null, "There is no debug information available."), React__default.createElement("span", null, "Please turn on debug and re-run your tests."))));
};

var RequestsModal$1 = React__default.memo(RequestsModal);

var ControlBar = function ControlBar() {
  var _useContext = React.useContext(AppContext),
      adapter = _useContext.adapter,
      config = _useContext.config;

  var _useState = React.useState(''),
      appLoc = _useState[0],
      setAppLoc = _useState[1];

  var _useState2 = React.useState(false),
      debug = _useState2[0],
      setDebug = _useState2[1];

  React.useEffect(function () {
    if (adapter) {
      adapter.setDebugState(debug);
    }
  }, [debug, adapter, config]);
  React.useEffect(function () {
    if (appLoc && adapter) {
      adapter.setSASjsConfig(_extends({}, adapter.getSasjsConfig(), {
        appLoc: appLoc
      }));
    }
  }, [appLoc, adapter]);
  React.useEffect(function () {
    setAppLoc(adapter.getSasjsConfig().appLoc);
  }, [adapter]);
  return React__default.createElement(semanticUiReact.Menu, {
    attached: "top",
    inverted: true,
    color: "blue",
    className: "control-bar"
  }, React__default.createElement(semanticUiReact.Menu.Item, null, React__default.createElement(semanticUiReact.Popup, {
    inverted: true,
    content: "Toggle debug mode",
    trigger: React__default.createElement(semanticUiReact.Checkbox, {
      toggle: true,
      onChange: function onChange(_, data) {
        return setDebug(!!data.checked);
      }
    })
  })), React__default.createElement(semanticUiReact.Menu.Item, null, React__default.createElement(semanticUiReact.Input, {
    className: "app-loc-input",
    placeholder: "App loc",
    value: appLoc,
    onChange: function onChange(_, data) {
      return setAppLoc(data.value);
    }
  })), React__default.createElement(semanticUiReact.Menu.Menu, {
    position: "right"
  }, React__default.createElement(semanticUiReact.Button, {
    onClick: function onClick() {
      return adapter.clearSasRequests();
    }
  }, "Clear requests"), React__default.createElement(RequestsModal$1, {
    trigger: React__default.createElement(semanticUiReact.Button, null, "Requests")
  })));
};

var TestSuiteCard = function TestSuiteCard(props) {
  var name = props.name,
      tests = props.tests,
      onRerun = props.onRerun,
      onRerunTest = props.onRerunTest;
  var overallStatus = tests.map(function (t) {
    return t.result;
  }).reduce(function (x, y) {
    return x && y;
  });
  var isSuiteRunning = tests.map(function (t) {
    return t.isRunning;
  }).reduce(function (x, y) {
    return x || y;
  });
  return React__default.createElement("div", {
    className: "test-suite"
  }, React__default.createElement("div", {
    className: "test-suite-name " + (isSuiteRunning ? 'running' : overallStatus ? 'passed' : 'failed')
  }, name, React__default.createElement("button", {
    className: "re-run-button " + (isSuiteRunning ? 'disabled' : ''),
    onClick: onRerun
  }, isSuiteRunning ? 'Running' : 'Re-run')), tests.map(function (completedTest, index) {
    var test = completedTest.test,
        result = completedTest.result,
        error = completedTest.error,
        executionTime = completedTest.executionTime,
        isRunning = completedTest.isRunning;
    var title = test.title,
        description = test.description;
    return React__default.createElement(TestCard, {
      key: index,
      title: title,
      onRerun: function onRerun() {
        return onRerunTest(test);
      },
      description: description,
      status: isRunning ? 'running' : result === true ? 'passed' : 'failed',
      error: error,
      executionTime: executionTime
    });
  }));
};

var runTest = function runTest(testToRun, context) {
  try {
    var test = testToRun.test,
        assertion = testToRun.assertion,
        beforeTest = testToRun.beforeTest,
        afterTest = testToRun.afterTest;
    var beforeTestFunction = beforeTest ? beforeTest : function () {
      return Promise.resolve();
    };
    var afterTestFunction = afterTest ? afterTest : function () {
      return Promise.resolve();
    };
    var startTime = new Date().valueOf();
    return Promise.resolve(beforeTestFunction().then(function () {
      return test(context);
    }).then(function (res) {
      return Promise.resolve(assertion(res, context));
    }).then(function (testResult) {
      afterTestFunction();
      var endTime = new Date().valueOf();
      var executionTime = (endTime - startTime) / 1000;
      return {
        result: testResult,
        error: null,
        executionTime: executionTime
      };
    })["catch"](function (e) {
      console.error(e);
      var endTime = new Date().valueOf();
      var executionTime = (endTime - startTime) / 1000;
      return {
        result: false,
        error: e,
        executionTime: executionTime
      };
    }));
  } catch (e) {
    return Promise.reject(e);
  }
};

var asyncForEach = function asyncForEach(array, callback) {
  try {
    var _temp2 = _forTo(array, function (index) {
      return Promise.resolve(callback(array[index], index, array)).then(function () {});
    });

    return Promise.resolve(_temp2 && _temp2.then ? _temp2.then(function () {}) : void 0);
  } catch (e) {
    return Promise.reject(e);
  }
};

var TestSuiteRunner = function TestSuiteRunner(props) {
  var testSuites = props.testSuites || [];

  var _useState = React.useState(false),
      runTests = _useState[0],
      setRunTests = _useState[1];

  var _useState2 = React.useState(null),
      currentTestSuite = _useState2[0],
      setCurrentTestSuite = _useState2[1];

  var _useState3 = React.useState(0),
      completedTestSuiteCount = _useState3[0],
      setCompletedTestSuiteCount = _useState3[1];

  var _useState4 = React.useState([]),
      completedTestSuites = _useState4[0],
      setCompletedTestSuites = _useState4[1];

  React.useEffect(function () {
    if (testSuites && testSuites.length) {
      setCurrentTestSuite(testSuites[0]);
    }
  }, [testSuites]);
  var resetTestSuiteResults = React.useCallback(function (testSuiteIndex) {
    var newCompletedTestSuites = immer.produce(completedTestSuites, function (draft) {
      draft[testSuiteIndex].completedTests.forEach(function (test) {
        test.isRunning = true;
        test.executionTime = null;
      });
    });
    setCompletedTestSuites(newCompletedTestSuites);
  }, [completedTestSuites]);
  var resetTestResults = React.useCallback(function (testSuiteIndex, testIndex, completedTestSuite) {
    var newCompletedTestSuite = immer.produce(completedTestSuite, function (draft) {
      draft.completedTests[testIndex] = _extends({}, draft.completedTests[testIndex], {
        isRunning: true,
        executionTime: null
      });
    });
    var newCompletedTestSuites = immer.produce(completedTestSuites, function (draft) {
      draft[testSuiteIndex] = newCompletedTestSuite;
    });
    setCompletedTestSuites(newCompletedTestSuites);
  }, [completedTestSuites]);
  var rerunTest = React.useCallback(function (test, testSuiteIndex, completedTestSuite) {
    try {
      var testIndex = completedTestSuite.completedTests.findIndex(function (t) {
        return t.test.title === test.title;
      });
      var originalTestSuite = testSuites.find(function (t) {
        return t.name === completedTestSuite.name;
      });
      return Promise.resolve(executeTest(originalTestSuite, test)).then(function (executionResult) {
        var newCompletedTestSuite = immer.produce(completedTestSuite, function (draft) {
          draft.completedTests[testIndex] = _extends({}, draft.completedTests[testIndex], executionResult, {
            isRunning: false
          });
        });
        var newCompletedTestSuites = immer.produce(completedTestSuites, function (draft) {
          draft[testSuiteIndex] = newCompletedTestSuite;
        });
        setCompletedTestSuites(newCompletedTestSuites);
      });
    } catch (e) {
      return Promise.reject(e);
    }
  }, [completedTestSuites]);
  var rerunTestSuite = React.useCallback(function (testSuiteIndex, completedTestSuite) {
    try {
      var originalTestSuite = testSuites.find(function (t) {
        return t.name === completedTestSuite.name;
      });
      var newCompletedTests = [];
      return Promise.resolve(asyncForEach(completedTestSuite.completedTests, function (completedTest) {
        try {
          return Promise.resolve(executeTest(originalTestSuite, completedTest.test)).then(function (result) {
            newCompletedTests.push(_extends({}, completedTest, result, {
              isRunning: false
            }));
            var newCompletedTestSuite = immer.produce(completedTestSuite, function (draft) {
              draft.completedTests = newCompletedTests;
            });
            var newCompletedTestSuites = immer.produce(completedTestSuites, function (draft) {
              draft[testSuiteIndex] = newCompletedTestSuite;
            });
            setCompletedTestSuites(newCompletedTestSuites);
          });
        } catch (e) {
          return Promise.reject(e);
        }
      })).then(function () {});
    } catch (e) {
      return Promise.reject(e);
    }
  }, [completedTestSuites]);
  return React__default.createElement("div", null, React__default.createElement(reactHelmet.Helmet, null, React__default.createElement("link", {
    rel: "stylesheet",
    href: "https://cdnjs.cloudflare.com/ajax/libs/semantic-ui/2.4.1/semantic.min.css"
  })), React__default.createElement(ControlBar, null), React__default.createElement("div", {
    className: "button-container"
  }, runTests ? React__default.createElement(semanticUiReact.Button, {
    primary: true,
    loading: true,
    size: "massive"
  }, "Running tests...") : React__default.createElement(semanticUiReact.Button, {
    icon: true,
    labelPosition: "left",
    primary: true,
    size: "massive",
    onClick: function onClick() {
      setRunTests(true);
      setCompletedTestSuiteCount(0);
    }
  }, React__default.createElement(semanticUiReact.Icon, {
    name: "play"
  }), "Run Tests")), React__default.createElement("div", {
    className: "test-suites"
  }, completedTestSuites.map(function (completedTestSuite, index) {
    return React__default.createElement(TestSuiteCard, {
      key: index,
      tests: completedTestSuite.completedTests,
      name: completedTestSuite.name,
      onRerun: function () {
        try {
          resetTestSuiteResults(index);
          return Promise.resolve(rerunTestSuite(index, completedTestSuite)).then(function () {});
        } catch (e) {
          return Promise.reject(e);
        }
      },
      onRerunTest: function (test) {
        try {
          var testIndex = completedTestSuite.completedTests.findIndex(function (t) {
            return t.test.title === test.title;
          });
          resetTestResults(index, testIndex, completedTestSuite);
          return Promise.resolve(rerunTest(test, index, completedTestSuite)).then(function () {});
        } catch (e) {
          return Promise.reject(e);
        }
      }
    });
  }), !!currentTestSuite && runTests && React__default.createElement(TestSuite, Object.assign({}, currentTestSuite, {
    isRunning: runTests,
    onCompleted: function onCompleted(name, completedTests) {
      setCompletedTestSuiteCount(function (c) {
        return c + 1;
      });
      var newCompletedTestSuites = [].concat(completedTestSuites, [{
        name: name,
        completedTests: completedTests
      }]);
      setCompletedTestSuites(newCompletedTestSuites);
      var currentIndex = testSuites.indexOf(currentTestSuite);
      var nextTestSuite = currentIndex === testSuites.length - 1 ? null : testSuites[currentIndex + 1];
      setCurrentTestSuite(nextTestSuite);

      if (completedTestSuiteCount + 1 === testSuites.length) {
        setRunTests(false);
      }
    }
  }))));
};

var executeTest = function executeTest(testSuite, test) {
  try {
    var _temp5 = function _temp5() {
      return Promise.resolve(runTest(test, {
        data: context
      }));
    };

    var context;

    var _temp6 = function () {
      if (testSuite !== null && testSuite !== void 0 && testSuite.beforeAll) {
        return Promise.resolve(testSuite.beforeAll()).then(function (_testSuite$beforeAll) {
          context = _testSuite$beforeAll;
        });
      }
    }();

    return Promise.resolve(_temp6 && _temp6.then ? _temp6.then(_temp5) : _temp5(_temp6));
  } catch (e) {
    return Promise.reject(e);
  }
};

exports.AppContext = AppContext;
exports.AppProvider = AppProvider;
exports.TestSuiteRunner = TestSuiteRunner;
//# sourceMappingURL=index.js.map
